"""Per-prefix data, mapping each prefix to a name.

Auto-generated file, do not edit by hand.
"""
from ..util import u

# Copyright (C) 2011-2020 The Libphonenumber Authors
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#  http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

TIMEZONE_DATA = {}
from .data0 import data
TIMEZONE_DATA.update(data)
del data
TIMEZONE_LONGEST_PREFIX = 8
